@@ -11,22 +11,22 @@ test_data <- function() {
   data = data.frame(x = c(xcl1[1:30],
                           xcl2[1:30],
                           xcl3[1:30],
-                          xcl1[31:60],
-                          xcl2[31:60],
-                          xcl3[31:60],
+                          # xcl1[31:60],
+                          # xcl2[31:60],
+                          # xcl3[31:60],
                           xcl1[61:90],
                           xcl2[61:90],
                           xcl3[61:90]),
                     y = c(ycl1[1:30],
                           ycl2[1:30],
                           ycl3[1:30],
-                          ycl1[31:60],
-                          ycl2[31:60],
-                          ycl3[31:60],
+                          # ycl1[31:60],
+                          # ycl2[31:60],
+                          # ycl3[31:60],
                           ycl1[61:90],
                           ycl2[61:90],
                           ycl3[61:90]))
-  true_data_segclust = rep(rep(seq(1,3),each = 30),3)
-  true_data_seg = rep(seq(1,9),each = 30)
+  true_data_segclust = rep(rep(seq(1,3),each = 30),2)
+  true_data_seg = rep(seq(1,6),each = 30)
   return( list( data = data, true_data_seg = true_data_seg, true_data_segclust = true_data_segclust))
 }
